<template>
  <div>
    <el-dialog
      :title="`流程基础配置：` + deployName"
      :visible.sync="processConfigShow"
      width="500px"
      :close-on-click-modal="false"
      :before-close="handleClose">

      <el-form :model="form" :rules="rules" ref="form" label-width="100px" class="demo-ruleForm">
        <el-form-item label="项目类型" prop="projectType">
          <el-select v-model="form.projectType" clearable placeholder="请选择项目类型">
            <el-option v-for="item in dict.type.sys_project_type" :key="item.value" :label="item.label"
                       :value="item.value"/>
          </el-select>
        </el-form-item>
        <el-form-item label="资金类型" prop="fundType">
          <el-select v-model="form.fundType" clearable placeholder="请选择资金类型">
            <el-option v-for="item in dict.type.sys_funding_type" :key="item.value" :label="item.label"
                       :value="item.value"/>
          </el-select>
        </el-form-item>
        <el-form-item label="投资类别" prop="investType">
          <el-select v-model="form.investType" clearable placeholder="请选择投资类别">
            <el-option v-for="item in dict.type.sys_investment_type" :key="item.value" :label="item.label"
                       :value="item.value"/>
          </el-select>
        </el-form-item>
        <el-form-item label="重点分类" prop="importanceType">
          <el-select v-model="form.importanceType" clearable placeholder="请选择重点分类">
            <el-option v-for="item in dict.type.sys_key_categories" :key="item.value" :label="item.label"
                       :value="item.value"/>
          </el-select>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="save">保存</el-button>
        <el-button @click="handleClose">取消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import {saveProcessConfigInfo, getProcessConfigInfoByDeploy} from "@/api/projectProcess/processConfigInfo"

export default {
  dicts: ['sys_project_type', 'sys_key_categories', 'sys_funding_type', 'sys_investment_type'],
  name: "EditProcessConfig",
  props: {
    processConfigShow: {
      require: true,
      type: Boolean
    },
    deployName: {
      require: true,
      type: String
    },
    form: {
      require: true,
      type: Object
    }
  },
  data() {
    return {
      rules: {
        projectType: [
          { required: true, message: '请选择项目类型', trigger: 'change' }
        ],
        fundType: [
          { required: true, message: '请选资金类型', trigger: 'change' }
        ],
        investType: [
          { required: true, message: '请选择投资类别', trigger: 'change' }
        ],
        importanceType: [
          { required: true, message: '请选择重点分类', trigger: 'change' }
        ],
      }
    }
  },
  methods: {
    save() {
      this.$refs['form'].validate((valid) => {
        if (valid) {
          saveProcessConfigInfo(this.form).then(res => {
            this.$message.success(res.msg)
            this.handleClose()
          })
        }
      });

    },
    handleClose() {
      this.$emit("close")
    }
  }
}
</script>

<style scoped>

</style>
